
WarRecord.Locale.CONFIG_TITLE = "War Record settings"

WarRecord.Locale.CONFIG_PAGE_HISTORY_LIMITS = "History limits"
WarRecord.Locale.CONFIG_PAGE_DATE_TIME = "Date/time"

WarRecord.Locale.CONFIG_MAX_ENTRIES = "Maximum entries in battle history:"
WarRecord.Locale.CONFIG_MAX_DETAILED_ENTRIES = "Maximum detailed entries in battle history:"
WarRecord.Locale.CONFIG_UNLIMITED = "Unlimited"

WarRecord.Locale.CONFIG_SERVER_TIME_OFFSET_DESC = "Server time offset"
WarRecord.Locale.FORMAT_SERVER_TIME_OFFSET_VALUE_SINGLE = "%+d hour"
WarRecord.Locale.FORMAT_SERVER_TIME_OFFSET_VALUE_PLURAL = "%+d hours"
WarRecord.Locale.CONFIG_TIMESTAMP_FORMAT_DESC = "Date format:"
WarRecord.Locale.TIMESTAMP_FORMATS = {
	"%d/%m",
	"%m/%d"
}
WarRecord.Locale.CONFIG_TIMESTAMP_FORMAT_HELP = "?"
WarRecord.Locale.CONFIG_TIMESTAMP_FORMAT_HELP_TOOLTIP = {
	"Date format",
	"%d - day",
	"%m - month",
	"%y - two-digit year",
	"%Y - full year"
}

WarRecord.Locale.CONFIG_APPLY = "Apply"
WarRecord.Locale.CONFIG_CANCEL = "Cancel"

local COMBOBOX_TEXT_WIDTH_OFFSET = 20

--------------------------------------------------------------------------------

function WarRecord.Config_OnLoad(frame)
	UIPanelBackdropFrame_SetTexture(frame, "Interface/Common/PanelCommonFrame", 256, 256)

	WarRecordConfigTitle:SetText(WarRecord.Locale.CONFIG_TITLE)
	WarRecordConfig_Version:SetText(WarRecord.VERSION_STR)

	-- Pages
	WarRecordConfig_PageList_HistoryLimits:SetText(WarRecord.Locale.CONFIG_PAGE_HISTORY_LIMITS)
	WarRecordConfig_PageList_DateTime:SetText(WarRecord.Locale.CONFIG_PAGE_DATE_TIME)

	-- Battle history size limits
	WarRecordConfig_HistoryLimits_MaxEntries_Text:SetText(WarRecord.Locale.CONFIG_MAX_ENTRIES)
	WarRecordConfig_HistoryLimits_MaxEntries_Checkbox_Text:SetText(WarRecord.Locale.CONFIG_UNLIMITED)

	WarRecordConfig_HistoryLimits_MaxDetailedEntries_Text:SetText(WarRecord.Locale.CONFIG_MAX_DETAILED_ENTRIES)
	WarRecordConfig_HistoryLimits_MaxDetailedEntries_Checkbox_Text:SetText(WarRecord.Locale.CONFIG_UNLIMITED)

	-- Time/date
	local min, max = -24, 24
	WarRecordConfig_DateTime_ServerTimeOffsetSliderDesc:SetText(WarRecord.Locale.CONFIG_SERVER_TIME_OFFSET_DESC)
	WarRecordConfig_DateTime_ServerTimeOffsetSlider:SetValueStepMode("INT")
	WarRecordConfig_DateTime_ServerTimeOffsetSlider:SetMinMaxValues(min, max)
	WarRecordConfig_DateTime_ServerTimeOffsetSliderLow:SetText(tostring(min))
	WarRecordConfig_DateTime_ServerTimeOffsetSliderHigh:SetText(tostring(max))
	WarRecordConfig_DateTime_ServerTimeOffsetSlider:SetValue(0)
	WarRecord.ConfigServerTimeOffset_OnValueChanged(WarRecordConfig_DateTime_ServerTimeOffsetSlider)  -- unless :SetValue(n) is called with a non-zero value

	WarRecordConfig_DateTime_TimestampFormatDesc_Text:SetText(WarRecord.Locale.CONFIG_TIMESTAMP_FORMAT_DESC)
	UIDropDownMenu_SetWidth(WarRecordConfig_DateTime_TimestampFormatComboBox, WarRecordConfig_DateTime_TimestampFormatComboBox:GetWidth() - COMBOBOX_TEXT_WIDTH_OFFSET)
	UIDropDownMenu_Initialize(WarRecordConfig_DateTime_TimestampFormatComboBox, WarRecord.ConfigTimestampFormatCB_CallbackShow)
	WarRecordConfig_DateTime_TimestampFormatHelpButton:SetText(WarRecord.Locale.CONFIG_TIMESTAMP_FORMAT_HELP)

	WarRecordConfig_ApplyButton:SetText(WarRecord.Locale.CONFIG_APPLY)
	WarRecordConfig_CancelButton:SetText(WarRecord.Locale.CONFIG_CANCEL)
end


function WarRecord.Config_OnShow(frame)
	frame:ResetFrameOrder()
	WarRecord.ConfigPageButton_OnClick(WarRecordConfig_PageList_HistoryLimits)

	WarRecordConfig_HistoryLimits_MaxEntries_EditBox:SetText(WarRecordSaves.maxEntries)
	WarRecordConfig_HistoryLimits_MaxEntries_Checkbox:SetChecked(WarRecordSaves.maxEntriesUnlimited)

	WarRecordConfig_HistoryLimits_MaxDetailedEntries_EditBox:SetText(WarRecordSaves.maxDetailedEntries)
	WarRecordConfig_HistoryLimits_MaxDetailedEntries_Checkbox:SetChecked(WarRecordSaves.maxDetailedEntriesUnlimited)

	WarRecordConfig_DateTime_ServerTimeOffsetSlider:SetValue(WarRecordSaves.serverTimeOffset)

	WarRecordConfig_DateTime_TimestampFormatComboBox_EditBox:SetText(WarRecordSaves.timestampFormat)
end


function WarRecord.Config_OnHide(frame)
	WarRecord_HelpTooltip:Hide()
end

--------------------------------------------------------------------------------

function WarRecord.ConfigPageButton_OnClick(frame)
	local id = frame:GetID()
	local i, v
	local configPageTable = {
		{button = WarRecordConfig_PageList_HistoryLimits, pageFrame = WarRecordConfig_HistoryLimits},
		{button = WarRecordConfig_PageList_DateTime,pageFrame = WarRecordConfig_DateTime}
	}

	for i, v in ipairs(configPageTable) do
		if (i == id) then
			v.button:LockHighlight()
			v.pageFrame:Show()
		else
			v.button:UnlockHighlight()
			v.pageFrame:Hide()
		end
	end

	WarRecord_HelpTooltip:Hide()
end

--------------------------------------------------------------------------------

function WarRecord.ConfigMaxEntriesEditBox_OnEditFocusLost(frame)
	local n = tonumber(frame:GetText())
	if not (n) then
		if (frame:GetParent():GetID() == 1) then
			frame:SetText(WarRecordSaves.maxEntries)
		elseif (frame:GetParent():GetID() == 2) then
			frame:SetText(WarRecordSaves.maxDetailedEntries)
		end
	end

	frame:HighlightText(0, 0)
end

--------------------------------------------------------------------------------

function WarRecord.ConfigServerTimeOffset_OnValueChanged(frame)
	local value = frame:GetValue()
	local valStr

	if (value == 1) or (value == -1) then
		valStr = string.format(WarRecord.Locale.FORMAT_SERVER_TIME_OFFSET_VALUE_SINGLE, value)
	else
		valStr = string.format(WarRecord.Locale.FORMAT_SERVER_TIME_OFFSET_VALUE_PLURAL, value)
	end
	getglobal(frame:GetName().."Value"):SetText(valStr)
end

--------------------------------------------------------------------------------

function WarRecord.ConfigTimestampFormatCB_CallbackShow()
	local i, v
	local buttonInfo
	local curFormat = WarRecordConfig_DateTime_TimestampFormatComboBox_EditBox:GetText()

	for k, v in pairs(WarRecord.Locale.TIMESTAMP_FORMATS) do
		buttonInfo = {}
		buttonInfo.text = v
		buttonInfo.value = v
		buttonInfo.func = WarRecord.ConfigTimestampFormatCB_CallbackDropDownClick
		if (curFormat == v) then
			buttonInfo.checked = 1
		end
		UIDropDownMenu_AddButton(buttonInfo, 1)
	end
end


function WarRecord.ConfigTimestampFormatCB_CallbackDropDownClick(button)
	WarRecordConfig_DateTime_TimestampFormatComboBox_EditBox:SetText(button:GetText())
end

--------------------------------------------------------------------------------

function WarRecord.ConfigTimestampFormatHelpButton_OnClick(frame)
	if (WarRecord_HelpTooltip:IsVisible()) then
		WarRecord_HelpTooltip:Hide()
	else
		local i
		WarRecord_HelpTooltip:SetOwner(frame, "ANCHOR_RIGHT", 2, 0)
		WarRecord_HelpTooltip:SetText(WarRecord.Locale.CONFIG_TIMESTAMP_FORMAT_HELP_TOOLTIP[1], 1, 1, 1)
		for i = 2, #(WarRecord.Locale.CONFIG_TIMESTAMP_FORMAT_HELP_TOOLTIP) do
			WarRecord_HelpTooltip:AddLine(WarRecord.Locale.CONFIG_TIMESTAMP_FORMAT_HELP_TOOLTIP[i], 1, 1, 0.7)
		end
		WarRecord_HelpTooltip:Show()
	end
end

--------------------------------------------------------------------------------

function WarRecord.ConfigApplyButton_OnClick(frame)
	local n

	n = tonumber(WarRecordConfig_HistoryLimits_MaxEntries_EditBox:GetText())
	if (n) then
		WarRecordSaves.maxEntries = n
	end

	n = tonumber(WarRecordConfig_HistoryLimits_MaxDetailedEntries_EditBox:GetText())
	if (n) then
		WarRecordSaves.maxDetailedEntries = n
	end

	WarRecordSaves.maxEntriesUnlimited = WarRecordConfig_HistoryLimits_MaxEntries_Checkbox:IsChecked()
	WarRecordSaves.maxDetailedEntriesUnlimited = WarRecordConfig_HistoryLimits_MaxDetailedEntries_Checkbox:IsChecked()

	WarRecordSaves.serverTimeOffset = WarRecordConfig_DateTime_ServerTimeOffsetSlider:GetValue()

	WarRecordSaves.timestampFormat = WarRecordConfig_DateTime_TimestampFormatComboBox_EditBox:GetText()

	WarRecord.TrimBattleHistory()
	WarRecord.BattleList_CreateSortableHistory()

	WarRecordConfig:Hide()
end


function WarRecord.ConfigCancelButton_OnClick(frame)
	WarRecordConfig:Hide()
end
